@@ -46,8 +46,8 @@ class Game:
             for j in range(-1, 2):
                 if i == 0 and j == 0:
                     continue
-                if not (x + i > 0 and x + i >= self.width or y + j < 0 or y + j >= self.height):
-                    if self.board[x+i][y+j] == 9:
+                if (x + i >= 0 and x + i < self.width) and (y + j >= 0 and y + j < self.height):
+                    if self.board[y + j][x + i] == 9:
                         count += 1
         return count
 
@@ -64,8 +64,9 @@ class Game:
         if self.board[y][x] == 0:
             for i in range(-1, 2):
                 for j in range(-1, 2):
-                    if self.board[y+i][x+j] != 9:
-                        self._reveal(x+i, y+j)
+                    if not (x < 0 or x >= self.width or y < 0 or y >= self.height):
+                        if self.board[y+i][x+j] != 9:
+                            self._reveal(x+i, y+j)
 
     def _flag(self, x, y):
         if self.player_board[y][x] == -1:
